@@ -10,6 +10,12 @@ sub call {
     $times_called >= $self->{_bound};
 }
 
+sub error_message {
+    my ($self, $mock_name, $name, $times_called) = @_;
+    sprintf "Expected '%s' to be called at least once on '%s', but called %d %s.",
+        $name, $mock_name, $times_called, ($times_called == 1 ? 'time' : 'times');
+}
+
 1;
 
 __END__
@@ -22,7 +28,7 @@ Test::Spec::RMock::AtLeastConstraint
 
 =head1 VERSION
 
-version 0.005001
+version 0.006
 
 =head1 AUTHOR
 
